@@ -122,7 +122,8 @@ void options::createCfg(){
     current_config<<"-fskip"<<QString("%1").arg(d->currentIndex());
     current_config<<"-fskip_value"<<QString("%1").arg(e->value());
     current_config<<"-fstype"<<QString("%1").arg(f->currentIndex());
-    current_config<<"-sound_buffer"<<QString("%1").arg(f->currentText());
+    current_config<<"-sound_buffer"<<QString("%1").arg(g->currentText());
+	current_config<<"-cdfile";
 
 }
 
